Introduction
============

named_arrays is an implementation of named tensors that includes support for linear algebra entities such as scalars, vectors and matrices.

.. autosummary::
    :toctree: _autosummary
    :template: module_custom.rst
    :recursive:

    named_arrays



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
